# Image analysis

From image, extracts the following information:
- Image data
    - Width
    - Height
- Characteristics
    - Contains nudity
- Faces
    - features (for facial recognition)
    - Face images
- Persons
    - Images of Persons
- Save to file share


## How to use
As method:

`results = process(record, image)`

As api:
 - Runs a flask servers accepting requests

`run_api()`